//=====================================================
// POV-Ray 3.5 Model
// IBM AS/400 R7200 Series 
// (c)2002 by Ive (all rights reversed)
// email: ive@lilysoft.com
//=====================================================
// Scale:
// 1 pov unit = 1 cm
//
// Hints: 
// This model requires high quality AA or focal blur 
// settings for good results. 
// Textures are designed for use with global_settings 
// assumed_gamma 1.0, ambient_light 1.0 and radiosity.
// See the example scene at the bottom of the file.
//
// Need:
// courbd.ttf     (courier bold)
// cyrvetic.ttf
// timrom.ttf    
// cd.png         (compact disk logo)
//=====================================================
// If you are able to create a *nice* looking image 
// by using this machine I would like to see it!
// Have fun - Ive
// ====================================================

#version 3.5;

// user controls
#ifndef (AS400Power)
  #declare AS400Power = on;  // Power switch, turns the control lamp and lights on/off
#end
     
#ifndef (AS400p1)          
  #declare AS400p1 = 0.87;
#end  
#ifndef (AS400p2)
  #declare AS400p2 = 0.62;
#end  
#ifndef (AS400p3)
  #declare AS400p3 = 0.36;
#end  
#ifndef (AS400p4)
  #declare AS400p4 = 0.21;
#end  

    
#declare TestScene = true;  // <- set true to render the test scene (at the bottom of this file) 
                            //    or false if you include the model in your own scene.

// ====================================================

#if (!AS400Power)
  #declare AS400p1 = 0.02;
  #declare AS400p2 = 0.02;
  #declare AS400p3 = 0.02;
  #declare AS400p4 = 0.02;
#end

//=======================================
//    TEXTURES
//=======================================

#local T_Base = texture {
  pigment {rgb <16, 16, 15>/255 }
  finish  {diffuse 0.3 specular 0.65 roughness 0.016 metallic 0.4 brilliance 2.1 reflection {0.01 0.07 falloff 2 metallic} } 
  normal {bumps 0.02 scale 1.3}
}

#local T_Metal = texture {
  pigment {rgb <52, 52, 51>/255 }
  finish  {diffuse 0.33 specular 0.8 roughness 0.007 metallic 1.0 brilliance 2.8 reflection{0.3 metallic} } 
}

#local T_BlackMetal = texture {
  pigment {rgb 0.085}
  finish  {diffuse 0.3 specular 0.6 roughness 0.006 metallic 1 brilliance 3 reflection {0.1 metallic} } 
}

#local T_GrayPlastic = texture {
  pigment {rgb 0.35 }
  finish  {diffuse 0.5 specular 0.5 roughness 0.011 metallic 1 brilliance 1.5 reflection{0.01 metallic} } 
  normal {bumps 0.01 scale 1.1}
}

#local T_Chrome = texture {
  pigment {rgb <0.61, 0.61, 0.60> }
  finish  {diffuse 0.1 specular 0.5 roughness 0.005 metallic 1 brilliance 4 reflection {0.5 metallic} } 
}

#local T_Grill = texture {
  pigment {rgb 0.06}
  finish {diffuse 0.2 specular 0.12 roughness 0.08 brilliance 2.5}
  normal {quilted 0.1 scale 5 }
}

#local T_Red = texture {
  pigment {rgb <112, 13, 5>/255 }
  finish  {diffuse 0.6 specular 0.3 roughness 0.02 metallic 0.5 brilliance 1.3}
}    

#local T_Text = texture {
  pigment {rgb 0.91}
  finish {diffuse 0.65 specular 0.3 roughness 0.02 metallic 0.4}
}

#local T_Glass = material {
  texture {
    pigment {rgbf 0.91}
    finish {diffuse 0.04 specular 0.8 roughness 0.004 reflection {0.99 fresnel} conserve_energy }
  }       
  interior {ior 1.55 fade_distance 2 fade_power 2}
}

#local T_CtrlLight = material {
  texture {
    pigment {rgbf <1.0, 0.7, 0.1, 0.7>}
    finish {diffuse 0.12 specular 0.3 roughness 0.003 reflection{0.8 fresnel falloff 2} conserve_energy}
  }
  interior {ior 1.5}  
}


//=======================================
//    OBJECTS
//=======================================

#include "Shapes.inc" 

#declare IBM = union {  // Big Blue LOGO   
// I
  box { <  0,   0, 0> < 15,  -2, 1> }
  box { <  0,  -4, 0> < 15,  -6, 1> }
  box { <  4,  -8, 0> < 11, -10, 1> }
  box { <  4, -12, 0> < 11, -14, 1> }
  box { <  4, -16, 0> < 11, -18, 1> }
  box { <  4, -20, 0> < 11, -22, 1> }
  box { <  0, -24, 0> < 15, -26, 1> }
  box { <  0, -28, 0> < 15, -30, 1> }
// B 
  box { < 18,   0, 0> < 37,  -2, 1> }
  box { < 18,  -4, 0> < 40,  -6, 1> }
  box { < 22,  -8, 0> < 28, -10, 1> } box { < 34,  -8, 0> < 40, -10, 1> }
  box { < 22, -12, 0> < 38, -14, 1> }
  box { < 22, -16, 0> < 38, -18, 1> }
  box { < 22, -20, 0> < 28, -22, 1> } box { < 34, -20, 0> < 40, -22, 1> }
  box { < 18, -24, 0> < 40, -26, 1> }
  box { < 18, -28, 0> < 37, -30, 1> }
// M
  box { < 43,   0, 0> < 56,  -2, 1> } box { < 64,   0, 0> < 76,  -2, 1> }
  box { < 43,  -4, 0> < 57,  -6, 1> } box { < 63,  -4, 0> < 76,  -6, 1> }
  box { < 48,  -8, 0> < 58, -10, 1> } box { < 62,  -8, 0> < 72, -10, 1> }
  box { < 48, -12, 0> < 59, -14, 1> } box { < 61, -12, 0> < 72, -14, 1> }
  box { < 48, -16, 0> < 54, -18, 1> } box { < 55, -16, 0> < 65, -18, 1> } box { < 66, -16, 0> < 72, -18, 1> }
  box { < 48, -20, 0> < 54, -22, 1> } box { < 56, -20, 0> < 64, -22, 1> } box { < 66, -20, 0> < 72, -22, 1> }
  box { < 43, -24, 0> < 54, -26, 1> } box { < 57, -24, 0> < 63, -26, 1> } box { < 66, -24, 0> < 76, -26, 1> }
  box { < 43, -28, 0> < 54, -30, 1> } box { < 58, -28, 0> < 62, -30, 1> } box { < 66, -28, 0> < 76, -30, 1> }
  translate y*30
}

#macro SCS(P1,P2,R)  
  sphere {P1, R}
  sphere {P2, R}
  cylinder {P1,P2,R open}
#end                

#local D = 1.5;

#local DriveBox = union {
  difference {
    box { <D, D, 0> <96-D, 28-D, 10> } 
    box { <9, D+2,-0.1 > <87, D+14, 9> }
  }
  box { <9, 0, 0> <87, 16, 1> rotate x*12 translate y*(D+2) }  
  SCS ( <D, D, D>, <96-D, D, D>, D )
  SCS ( <D, 28-D, D>, <96-D, 28-D, D>, D )
  cylinder { <D, D, D> <D, 28-D, D> D}
  cylinder { <96-D, D, D> <96-D, 28-D, D> D}
}

#local CoverBox = union {
  box { <D, D, 0>, <96-D, 28-D, 10> } 
  SCS ( <D, D, D>, <96-D, D, D>, D )
  SCS ( <D,28-D, D>, <96-D, 28-D, D>, D )
  cylinder { <D, D, D> <D, 28-D, D> D}
  cylinder { <96-D, D, D> <96-D, 28-D, D> D}
}

#local CdBox = union { 
  difference {
    box { < D,  D, 0>   <96-D,28-D, 10> } 
    box { < 7, 14,-0.1> <89, 25, 5> }
    box { <37, 13,-0.1> <59, 15, 5> }
    cylinder { <10, 8, -0.1> <10, 8, 8> 2 }
    box { <16, 6.5, -0.1> <28, 9.5, 5> }
    box { <32, 7, -0.1> <38,  9, 5> }
    box { <77, 6.5, -0.1> <87, 9.5, 5> }
  }                    
  cylinder { < 7, 14, 2> <37, 14, 2> 2} 
  cylinder { <59, 14, 2> <89, 14, 2> 2} 
  cylinder { < 7, 25, 2> <89, 25, 2> 2}
  cylinder { < 7, 14, 2> < 7, 25, 2> 2}
  cylinder { <89, 14, 2> <89, 25, 2> 2} 
  
  sphere {<37, 14, 2> 2}
  sphere {<59, 14, 2> 2}
  cylinder {<37, 14, 2> <37, 13, 2> 2} 
  cylinder {<59, 14, 2> <59, 13, 2> 2} 
  cylinder {<37, 13, 2> <59, 13, 2> 2} 
  
  union {
    box { <9, 16, 0> <87, 23, 5> }
    SCS ( <9, 16, 1>, <87, 16, 1> 1  )
    SCS ( <9, 23, 1>, <87, 23, 1> 1  )
    cylinder { < 9, 16, 1> < 9, 23, 1> 1}
    cylinder { <87, 16, 1> <87, 23, 1> 1}
    height_field {png "cd" smooth
      rotate -x*90 
      scale <8, 4, 0.3>  
      translate <43, 18, 0.1> 
    }       
  }
  
  SCS ( <D, D, D>, <96-D, D, D>, D )
  SCS ( <D, 28-D, D>, <96-D, 28-D, D>, D )
  cylinder { <D, D, D> <D, 28-D, D> D}
  cylinder { <96-D, D, D> <96-D, 28-D, D> D}
  
  torus { 1.9 0.5 rotate x*90 translate <10,8,0> texture {T_Metal} }
  box { <32, 7, 0.4> <38,  9, 1.1> material {T_Glass} }
  cylinder { <22,7,8> <22,9,8> 9 } 
  
  object{Round_Box_Union(<77.4, 6.9, -1.5> <86.6, 9.1,4> 0.9) texture{T_Chrome} }
  
  texture {T_Base}
}                                  

#macro Cpu(Value)
  texture {
    pigment{gradient x 
      color_map{ [Value rgb <0.10,0.55,0>] [Value rgb 0.21] } 
      scale 20
    }   
   #if (AS400Power)
    finish {ambient 0.35 diffuse 0.2}
   #else
    finish {ambient 0.0 diffuse 0.3}
   #end
  }  
#end

#macro Txt(S,P)
  text {ttf "cyrvetic.ttf" S 1 0 scale <2.5,2.5,1> texture {T_Text} translate P }
#end 

#local Button = union {     
  cone { <0,0,0> 4 <0,0,-1> 3 }
  cylinder { <0,0,-1> <0,0,-3> 3 } 
  torus { 2.5, 0.5 rotate x*90 translate -z*3 }
  cylinder { <0,0,-3> <0,0,-3.4> 2.5 }
  box { <-0.15, 2.6, -3.4> <0.15, 0.8, -3.5> texture {T_Text} }
  texture {T_BlackMetal}
} 

#local ControlBox1 = union {  
  difference {
    box { <D, D, 0>, <96-D, 34-D, 10> }
    box { <10, 4,-0.1> <30, 7, 2> }
    box { <10,11,-0.1> <30,14, 2> }
    box { <10,18,-0.1> <30,21, 2> }
    box { <10,25,-0.1> <30,28, 2> }
    cylinder { <56, 9, -0.1> <56, 9, 2> 2}
  }  
  SCS ( <D, D, D>, <96-D, D, D>, D )
  SCS ( <D, 34-D, D>, <96-D, 34-D, D>, D )
  cylinder { <D, D, D> <D, 34-D, D> D}
  cylinder { <96-D, D, D> <96-D, 34-D, D> D} 
  
  box { <0,0,1.2> <20,3,1.3> Cpu(AS400p4) translate<10, 4,0>}
  box { <0,0,1.2> <20,3,1.3> Cpu(AS400p3) translate<10,11,0>}
  box { <0,0,1.2> <20,3,1.3> Cpu(AS400p2) translate<10,18,0>}
  box { <0,0,1.2> <20,3,1.3> Cpu(AS400p1) translate<10,25,0>}
  
  box { <10, 4, 0.2> <30, 7, 0.7> material {T_Glass} }
  box { <10,11, 0.2> <30,14, 0.7> material {T_Glass} }
  box { <10,18, 0.2> <30,21, 0.7> material {T_Glass} }
  box { <10,25, 0.2> <30,28, 0.7> material {T_Glass} }
  
  Txt( "1", <8,25.5,-0.1> )
  Txt( "2", <8,18.5,-0.1> )
  Txt( "3", <8,11.5,-0.1> )
  Txt( "4", <8, 4.5,-0.1> )    
  Txt( "Processors", <11,29.5,-0.1> ) 
  Txt( "low", <11,8,-0.1> )
  Txt( "high", <25,8,-0.1> )
  
  Txt( "Power"  <60, 24, -0.15> )
  Txt( "Reset"  <60, 21, -0.15> )
  Txt( "Off"    <60, 18, -0.15> )
  Txt( "Test"   <60, 15, -0.15> )
  
  Txt( "Kbd"    <60,  8, -0.15> )
                                     
  difference {                                   
    box { <51,3,-0.1> <93,31,0.1> texture {T_GrayPlastic} }
    box { <54,24,-0.2> <58,26, 0.2> }
    box { <54,21,-0.2> <58,23, 0.2> }
    box { <54,18,-0.2> <58,20, 0.2> }
    box { <54,15,-0.2> <58,17, 0.2> }
    cylinder { <56, 9, -0.2> <56, 9, 0.2> 2}
  }               
  torus { 2.3 0.6 rotate x*90 translate <56,9,-0.05> texture {T_Metal} }
  
 #if (AS400Power)
  box { <54,24, 0.0> <58,26, -0.01> pigment {rgb <0.8, 0.7, 0.1>} finish {ambient 0.4 diffuse 0.2} }
 #end 
  box { <54,24,-0.2> <58,26, -0.02> material {T_Glass} }
  box { <54,21,-0.2> <58,23, -0.02> material {T_Glass} }
  box { <54,18,-0.2> <58,20, -0.02> material {T_Glass} }
  box { <54,15,-0.2> <58,17, -0.02> material {T_Glass} }
  
  union {                
    cylinder { <-5,0,0,> <5,0,0> 3 scale <1,1,0.5> }
    sphere { <-5,0,0> 3 scale <1,1,0.5> }
    sphere { < 5,0,0> 3 scale <1,1,0.5> } 
    cylinder { <-5,0,0> <-5,0,2> 3 }
    cylinder { < 5,0,0> < 5,0,2> 3 }
    box { <-5,-3,0> <5,3,2> }    
    cylinder { <4.5,0,2> <4.5,0,4> 2 }
          
    translate <80,24,-3>
    texture {T_BlackMetal}
  }
  
  texture {T_Base} 
}

#local ControlBox2 = union {
  difference {
    box { <D, D, 0>, <96-D, 34-D, 10> } 
    box { <12, 21, -0.1>, <35,29,2> }
    box { <73, 1.5, -0.1>, <83, 11.5, 2> }
  }  
  SCS ( <D, D, D>, <96-D, D, D>, D )
  SCS ( <D, 34-D, D>, <96-D, 34-D, D>, D )
  cylinder { <D, D, D> <D, 34-D, D> D}
  cylinder { <96-D, D, D> <96-D, 34-D, D> D}

  box { <12, 21, 0.2>, <35,29, 0.8> material{T_Glass} }
  box { <12, 21, 1.4>, <35,29, 1.5> 
    texture{
      pigment {rgb <0.09, 0.30, 0.01> }
     #if (AS400Power)
      finish {ambient 0.35 diffuse 0.2}
     #else 
      finish {ambient 0.0 diffuse 0.3}
     #end 
    } 
  }  
  #if (AS400Power)
    union {
      text {ttf "courbd" ">root/povray/" 1 0 scale <1.3,1.3,1>
        translate <12.5,26.5,1.3>
      }  
      text {ttf "courbd" ">pvengine as400.pov -w600-h800" 1 0 scale <1.3,1.3,1>
        translate <12.5,24.6,1.3>
      }  
      text {ttf "courbd" ">_" 1 0 scale <1.3,1.3,1>
        translate <12.5,22.7,1.3>
      }  
      texture{
        pigment {rgb <0.0, 0.1, 0.0> }
        finish {ambient 0.30 diffuse 0.2}
      }
    }  
  #end
  
  difference {
    superellipsoid { <0.22, 0.22> } 
    sphere { <0,0,-4.715> 3.8 }
    scale 4.6 
    translate <78, 6.5, 1.5>
    texture{T_GrayPlastic}
  }
  
  object {Button rotate -z*23 translate <48, 26,-0.8> }   
  object {Button rotate -z*88 translate <59, 26,-0.8> }   
  object {Button rotate -z*1  translate <48,  8,-0.8> }   
  object {Button rotate -z*1  translate <59,  8,-0.8> }   
  
  union {
    torus {2.5 0.7 rotate x*90  texture{T_Chrome} }
    cylinder { <0,0,0> <0,0,0.7> 2.5 texture {T_Chrome} }
    sphere { 0, 2.5 material {T_CtrlLight} }
   #if (AS400Power)
    light_source { <0,0,-1.5> rgb <1.0, 0.7, 0.1>*12 fade_distance 1 fade_power 2}
   #end 
    translate <88.5, 8, -0.1>
  }  
  
  texture {T_BlackMetal} 
}


#declare AS400 = union { 

// The unit measurement is a little bit strange but
// useful for medelling. 
// Scaled to 1 unit = 1 cm at end of union!
#local RB=2.0;    // border radius
#local W=385-RB;
#local H=368-RB;
#local D=195;
  
// top box
  union {
    difference {
      box { <RB,RB,0> <W, H, 36> }

      box { < 80, 215, -0.1> <174, H+0.1, 10> }
      box { <212, 215, -0.1> <308, H+0.1, 10> }
      
      box { <80,0,-0.1> <82,215,1> }
      
      box { <15,  0,0> < 80.1, 60, 29> translate <0,RB,-0.001> }   
      box { <81.9,0,0> <  368, 60, 29> translate <0,RB,-0.001> }
      
      box { <15, 232, -0.1> < 75, 252, 35> }
      box { <65, 251, -0.1> < 75, 262, 35>} 

      box { <35, 272, -0.1> < 75, 282, 35> }
      box { <55, 281, -0.1> < 75, 292, 35>} 

      box { <45, 302, -0.1> < 75, 312, 35> }
      box { <55, 311, -0.1> < 75, 322, 35>} 
      
      box { <45, 332, -0.1> < 75, 342, 35> }
      box { <65, 341, -0.1> < 75, 352, 35>}  
      
      box { <312, 232, -0.1> <369, 252, 35> }
      box { <312, 251, -0.1> <322, 262, 35> }
      
      box { <312, 272, -0.1> <342, 283, 35> }
      box { <312, 282, -0.1> <352, 292, 35> }

      box { <312, 302, -0.1> <332, 313, 35> }
      box { <312, 312, -0.1> <357, 322, 35> }

      box { <312, 332, -0.1> <322, 343, 35> }
      box { <312, 342, -0.1> <332, 352, 35> }
      
      cone { <73,177,-0.01> 9 <73,177,1> 7.1}
    }
                      
    difference {                  
      box { <0,0,0> <96, 21, 1> rotate x*18 translate < 80, 215, 0> }
      box { <79.9, 214, -0.1> <82, 217, 1> }
    }  
    box { <0,0,0> <96, 21, 1> rotate x*18 translate <212, 215, 0> }

    box { <0,0,0> <96,-21, 1> rotate -x*21 translate < 80, H, 0> }
    box { <0,0,0> <96,-21, 1> rotate -x*21 translate <212, H, 0> }
    
    #local C=1.1;     

    cylinder { <312, 232, C> <369, 232, C> C}
    cylinder { <312, 242, C> <369, 242, C> C}
    cylinder { <312, 252, C> <369, 252, C> C}
    cylinder { <312, 262, C> <322, 262, C> C}
    cylinder { <312, 232, C> <312, 262, C> C}
    cylinder { <322, 232, C> <322, 262, C> C}
    cylinder { <332, 232, C> <332, 252, C> C}
    cylinder { <359, 232, C> <359, 252, C> C}
    cylinder { <369, 232, C> <369, 252, C> C}  

    cylinder { <312, 272, C> <342, 272, C> C}
    cylinder { <312, 282, C> <352, 282, C> C}
    cylinder { <312, 292, C> <352, 292, C> C}
    cylinder { <312, 272, C> <312, 292, C> C}
    cylinder { <322, 272, C> <322, 292, C> C}
    cylinder { <332, 272, C> <332, 292, C> C}
    cylinder { <342, 272, C> <342, 292, C> C}
    cylinder { <352, 282, C> <352, 292, C> C}

    cylinder { <312, 302, C> <332, 302, C> C}
    cylinder { <312, 312, C> <357, 312, C> C}
    cylinder { <312, 322, C> <357, 322, C> C}
    cylinder { <312, 302, C> <312, 322, C> C} 
    cylinder { <322, 302, C> <322, 322, C> C} 
    cylinder { <332, 302, C> <332, 322, C> C} 
    cylinder { <357, 312, C> <357, 322, C> C} 

    cylinder { <312, 332, C> <322, 332, C> C}
    cylinder { <312, 342, C> <332, 342, C> C}
    cylinder { <312, 352, C> <332, 352, C> C} 
    cylinder { <312, 332, C> <312, 352, C> C}
    cylinder { <322, 332, C> <322, 352, C> C}
    cylinder { <332, 342, C> <332, 352, C> C}

    
    cylinder { <15, 232, C> <75, 232, C> C }
    cylinder { <15, 242, C> <75, 242, C> C }
    cylinder { <15, 252, C> <75, 252, C> C }
    cylinder { <65, 262, C> <75, 262, C> C } 
    cylinder { <15, 232, C> <15, 252, C> C }
    cylinder { <45, 232, C> <45, 252, C> C }
    cylinder { <55, 232, C> <55, 252, C> C }
    cylinder { <65, 232, C> <65, 262, C> C }
    cylinder { <75, 232, C> <75, 262, C> C }
    
    cylinder { <35, 272, C> <75, 272, C> C}
    cylinder { <35, 282, C> <75, 282, C> C}
    cylinder { <55, 292, C> <75, 292, C> C}
    cylinder { <35, 272, C> <35, 282, C> C}
    cylinder { <45, 272, C> <45, 282, C> C}
    cylinder { <55, 272, C> <55, 292, C> C}
    cylinder { <65, 272, C> <65, 292, C> C}
    cylinder { <75, 272, C> <75, 292, C> C}

    cylinder { <45, 302, C> <75, 302, C> C}
    cylinder { <45, 312, C> <75, 312, C> C}
    cylinder { <55, 322, C> <75, 322, C> C}
    cylinder { <45, 302, C> <45, 312, C> C}
    cylinder { <55, 302, C> <55, 322, C> C}
    cylinder { <65, 302, C> <65, 322, C> C}
    cylinder { <75, 302, C> <75, 322, C> C}
    
    cylinder { <45, 332, C> <75, 332, C> C}
    cylinder { <45, 342, C> <75, 342, C> C}
    cylinder { <65, 352, C> <75, 352, C> C}
    cylinder { <45, 332, C> <45, 342, C> C}
    cylinder { <55, 332, C> <55, 342, C> C}
    cylinder { <65, 332, C> <65, 352, C> C}
    cylinder { <75, 332, C> <75, 352, C> C}

               
    box { <15,  0,0> < 80.1, 75, 1> texture {T_Red} rotate x*15 translate <0,RB,0.5> }
    box { <81.9,0,0> <  368, 75, 1> texture {T_Red} rotate x*15 translate <0,RB,0.5> }
    
    SCS(< RB,  RB, RB>, < RB,  RB, D>, RB) 
    SCS(<  W,  RB, RB>, <  W,  RB, D>, RB) 
    SCS(< RB,   H, RB>, < RB,   H, D>, RB) 
    SCS(<  W,   H, RB>, <  W,   H, D>, RB) 
    cylinder{<RB,  RB, RB>,  <RB,  H, RB>, RB}
    cylinder{< W,  RB, RB>,  < W,  H, RB>, RB}
    cylinder{<RB,  RB, RB>,  < W, RB, RB>, RB}
    cylinder{<RB,   H, RB>,  < W,  H, RB>, RB}
    cylinder{<RB,  RB, D>, <RB,  H, D>, RB}
    cylinder{< W,  RB, D>, < W,  H, D>, RB}
    cylinder{<RB,  RB, D>, < W, RB, D>, RB}
    cylinder{<RB,   H, D>, < W,  H, D>, RB} 
    
    box { <  0, RB, RB> <  1,  H, D> } // left side
    box { <384, RB, RB> <385,  H, D> } // right side
    box { < RB,367, RB> < W, 368, D> } // top side
    box { < RB, RB,  D> < W, H, D+1> } // rear side
    
    text {ttf "timrom.ttf" "AS/400" 0.2 0 scale <13,13,1> translate <93,165,-0.1 > texture {T_Text} }
    object {IBM scale <0.4, 0.4, 1> translate <15,201,-0.1> texture {T_Text} }
    
    union {
      torus { 5.2, 1 rotate x*90 }
      difference {
        cylinder { <0,0,-1> <0,0,1> 5.2 }
        box { <-3.6,-0.5,-1.1> <3.6,0.5,0.9> }
      }                        
      texture {T_Metal}
      translate <73, 177, 0.2>
    }      
    
    object {CdBox    texture {T_Base} translate <80, 326, 4.2> }
    object {DriveBox texture {T_Base} translate <80, 298, 4.5> }
    object {ControlBox1 translate <80, 264, 4.5> }
    object {ControlBox2 translate <80, 230, 4.0> }

    object {DriveBox texture {T_Base} translate <212, 326, 4.5> }
    object {DriveBox texture {T_Base} translate <212, 298, 4.5> }
    object {DriveBox texture {T_Base} translate <212, 270, 4.5> }
    object {CoverBox texture {T_Base} translate <212, 242, 4.5> }
    object {CoverBox texture {T_Base} translate <212, 214, 4.5> }
   
    translate y*251  
  }    

// bottom box
  union {
    Round_Box_Union(<0,0,0>, <385, 234, D+RB>, RB)
    box { <15, 13,-0.4> <368,140,1> texture {T_Grill} }
    box { <15,155,-0.4> <368,220,1> texture {T_Grill} }
    
    translate y*16
  }     
  
  box { <5,250,5> <380,251,155> }
  
 #local Foot=union {
   cylinder { 0, y*16, 12} 
   torus { 12, 3 translate y*3}
   texture {T_Metal}
 }
                   
  object {Foot translate < 25, 0,  25> }
  object {Foot translate <360, 0,  25> }
  object {Foot translate < 25, 0, D+RB-25> }
  object {Foot translate <360, 0, D+RB-25> }
  
  texture {T_Base}
  
  scale 0.162  // scale down to real size: 1 pov unit = 1 cm
}

                            
                            
////////////////////////////
//  ***  TEST SCENE  ***  //
////////////////////////////
  
#if (TestScene)
  
#default { finish {ambient 0 diffuse 0.6} }   // !!!

global_settings {       
  ambient_light 1.0     
  assumed_gamma 1.0     
  adc_bailout   1/256
  max_trace_level 16
  radiosity {}        // the (poor) default settings
}

#declare T_Floor = 
texture {    
  pigment {checker rgb 0.24 rgb 0.42 scale 25} 
  finish {diffuse 0.6 specular 0.1 reflection {0.01 0.1 falloff 2} conserve_energy}
}                                                        
texture { 
  pigment {
    granite 
    color_map {[0 rgbt 1.00] [1 rgbt 0.75] } 
    scale 3
  }
}               

#declare T_Wall1 = texture {
  pigment { 
    wrinkles              
    color_map {[0 rgb <0.72, 0.68, 0.67>*0.96 ][1 rgb <0.7, 0.67, 0.65>*1.05]}       
    turbulence 0.1 scale 4.5  
  }            
  normal {granite 0.2 scale 2}
  finish {diffuse 0.8}
}

#declare T_Wall2 = texture {
  pigment { 
    granite 
    color_map {[0 rgb <0.72, 0.71, 0.45>*0.93 ][1 rgb <0.72, 0.71, 0.45>*1.00]}       
    turbulence 0.1 scale 3  
  }
  finish {diffuse 0.75}
}

plane { y, 0 texture{T_Floor} }
plane {-y, 0 pigment {rgb 0.8} finish {diffuse 0.75} translate y*300}
plane {-z, 0 texture {T_Wall1} }
plane { z, 0 texture {T_Wall1} translate -z*300}
plane { x, 0 texture {T_Wall2} translate -x*300}
plane {-x, 0 texture {T_Wall2} translate  x*100}

light_source {<-100, 200, -160> rgb <0.96, 0.99, 0.97>*100
//  area_light <25,0,0> <0,0,25> 6,6 adaptive 2 jitter
  fade_distance 10 fade_power 2
}

object {AS400 translate <0,0,-45> }


camera { // main
   location < 75,  60, -150>
   right x*image_width/image_height
   look_at  < 35,  55, -45>
   angle 60
} 
  

/*                     
camera { // detail
   location < 22, 75, -110>
   right x*image_width/image_height
   look_at  < 21, 80, -45>
   angle 40
} 
*/
  
/*  
camera { // front view
   location < 31.1, 70, -128>
   right x*image_width/image_height
   look_at  < 31.1, 76, -45>
   angle 40
} 
*/


#end  
